@@ -1,5 +1,5 @@
 package Config::From::Backend::File;
-$Config::From::Backend::File::VERSION = '0.04';
+$Config::From::Backend::File::VERSION = '0.05';
 
 use utf8;
 use Moose;
@@ -39,7 +39,7 @@ Config::From::Backend::File -  File Backend for Config::From
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -49,6 +49,17 @@ version 0.04
 
 =head1 SUBROUTINES/METHODS
 
+=head2 file
+
+  The file to load from diffrents file format. It use Config::Any
+
+=head2 datas
+
+  The data returned by the backend
+
+=head1 SEE ALSO
+
+L<Config::Any>
 
 =head1 AUTHOR
 
@@ -56,5 +67,4 @@ Daniel Brosseau, C<< <dab at catapulse.org> >>
 
 =cut
 
-
 1; # End of Config::From::Backend::File
